===============================
Nose-Watcher
===============================

.. image:: https://badge.fury.io/py/nose-watcher.png
    :target: http://badge.fury.io/py/nose-watcher

.. image:: https://travis-ci.org/solarnz/nose-watcher.png?branch=master
        :target: https://travis-ci.org/solarnz/nose-watcher

.. image:: https://pypip.in/d/nose-watcher/badge.png
        :target: https://pypi.python.org/pypi/nose-watcher

.. image:: https://coveralls.io/repos/solarnz/nose-watcher/badge.png?branch=master
        :target: https://coveralls.io/r/solarnz/nose-watcher?branch=master


A nose plugin to watch for changes within the local directory.

* Free software: BSD license
* Documentation: http://nose-watcher.readthedocs.org.

Features
--------

* TODO
